getting started
================

.. grid:: 2
   :margin: 3
   :padding: 2
   :gutter: 3 3 3 3

   .. grid-item-card:: :material-twotone:`start;2em;sd-text-success` Getting started
      :class-card: sd-border-0

      - :doc:`installation`
      - :doc:`drain-swamp-files`
      - :doc:`setuptools-scm`


   .. grid-item-card:: :material-twotone:`hot_tub;2em;sd-text-success` How to
      :class-card: sd-border-0

      - :doc:`from-source`
      - :doc:`build-package`
